require 'fundraising_project/project'

module CrowdFund
  describe Project do

    before do
      @project = Project.new("my_project")
      @current_funding_amount = @project.current_funding_amount 
    end

    before do
      $stdout = StringIO.new
    end  

    it "should have an initial target funding amount" do
      expect(@project.target_funding_amount).not_to be_nil
    end

    it 'should have "funding needed"" equal to "target funding" - "initial funding"' do
      expect(@project.funding_needed).to eq(@project.target_funding_amount - @project.current_funding_amount)
    end

    it "should increase funds by 25 when funds are added" do
      @project.add_funds
      expect(@project.current_funding_amount).to eq(@current_funding_amount + 25)
    end  

    it "should decrease funds by 15 when funds are removed" do
      @project.remove_funds
      expect(@project.current_funding_amount).to eq(@current_funding_amount - 15)
    end    

    it "should have a default value of 0 for funding amount" do
      expect(@project.current_funding_amount).to eq(0)
    end

    context "with excess funds" do
      before do
        @project = Project.new("test_project", 1111, 1000)
      end    
      it "should have 'fully funded' equal to true" do
        expect(@project).to be_fully_funded
      end    
    end

    context "with exactly the target amount of funds" do
      before do
        @project = Project.new("test_project", 1000, 1000)
      end    
      it "should have 'fully funded' equal to true" do
        expect(@project).to be_fully_funded
      end    
    end  

    context "with less than the target amount of funds" do
      before do
        @project = Project.new("test_project", 800, 1000)
      end    
      it "should have 'fully funded' equal to false" do
        expect(@project).not_to be_fully_funded
      end    
    end  
  end
end